@@ -23,27 +23,45 @@ def set_extension(
 
 def get_token_parent_span(
     token: Token,
+    min_length: int,
 ) -> Span:
     """Takes a Token object and returns its Span from the parent Doc.
 
     Args:
         token (Token): spacy Token object to get the parent span of.
+        min_length (int): Minimum length of parent span. This will be ignored
+            if the sentence itself is shorter min_length.
 
     Returns:
         Span: spacy Span object containing the Token passed into the function.
     """
+    def get_children_indices(head: Token) -> list:
+        """Recursively gets indices of head's children and children of children.
+
+        Args:
+            head (Token): Token to get the indices of children for.
+
+        Returns:
+            list: List of indices of child tokens (indices are the locations of
+                the children within the parent Doc object).
+        """
+        indices = [token.i for token in head.children]
+        indices.append(head.i)
+        for child in head.children:
+            indices.extend(get_children_indices(child))
+        indices.sort()
+        return indices
+
+    indices = get_children_indices(token.head)
     doc = token.doc
-    head = token.head
-    siblings = head.children
-    indices = [token.i for token in siblings]
-    indices.append(head.i)
-    indices.sort()
     first = indices[0]
     last = indices[-1]
     if last >= len(doc):
         span = doc[first:]
     else:
         span = doc[first:last+1]
+    if len(span) < min_length and token.head != token.head.head:
+        span = get_token_parent_span(token.head, min_length=min_length)
     return span
 
 def contains_aspect(
@@ -193,6 +211,7 @@ def keyword_aspects(
 def parent_span(
     doc: Doc,
     include_non_keywords: bool = False,
+    min_length: int = 7,
 ) -> Doc:
     """Takes a Doc and adds the 'parent_span' attribute to its Token objects.
 
@@ -212,6 +231,9 @@ def parent_span(
             on.
         include_non_keywords (bool, optional): Whether or not to assign spans to
             non-keyword Token objects. Defaults to False.
+        min_length (int, optional): Minimum span length to enforce. Spans
+            shorter than the minimum length will be expanded. Set to 0 to
+            disable expansion.
 
     Raises:
         ValueError: Raised if passing a non-bool object to include_non_keywords.
@@ -232,8 +254,8 @@ def parent_span(
         raise ValueError('include_non_keywords takes only True or False')
 
     for token in tokens:
-        span = get_token_parent_span(token)
-        token._.parent_span = span          
+        span = get_token_parent_span(token, min_length=min_length)
+        token._.parent_span = span
 
     return doc
 
